@@ -24,6 +24,7 @@ from solum.tests import base
 from solum.tests import fakes
 
 
+@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.component_handler.ComponentHandler')
@@ -32,8 +33,9 @@ class TestComponentController(base.BaseTestCase):
         super(TestComponentController, self).setUp()
         objects.load()
 
-    def test_component_get(self, ComponentHandler, resp_mock, request_mock):
-        self.policy({'show_component': '@'})
+    def test_component_get(self, ComponentHandler, resp_mock,
+                           request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = ComponentHandler.return_value.get
         fake_component = fakes.FakeComponent()
         hand_get.return_value = fake_component
@@ -47,8 +49,8 @@ class TestComponentController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
 
     def test_component_get_not_found(self, ComponentHandler,
-                                     resp_mock, request_mock):
-        self.policy({'show_component': '@'})
+                                     resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = ComponentHandler.return_value.get
         hand_get.side_effect = exception.ResourceNotFound(
             name='component', component_id='test_id')
@@ -58,8 +60,8 @@ class TestComponentController(base.BaseTestCase):
         self.assertEqual(404, resp_mock.status)
 
     def test_component_put_none(self, ComponentHandler,
-                                resp_mock, request_mock):
-        self.policy({'update_component': '@'})
+                                resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = None
         request_mock.content_type = 'application/json'
         hand_put = ComponentHandler.return_value.put
@@ -68,8 +70,8 @@ class TestComponentController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_component_put_not_found(self, ComponentHandler,
-                                     resp_mock, request_mock):
-        self.policy({'update_component': '@'})
+                                     resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         json_update = {'user_id': 'foo', 'name': 'appy'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -80,8 +82,9 @@ class TestComponentController(base.BaseTestCase):
         hand_update.assert_called_with('test_id', json_update)
         self.assertEqual(404, resp_mock.status)
 
-    def test_component_put_ok(self, ComponentHandler, resp_mock, request_mock):
-        self.policy({'update_component': '@'})
+    def test_component_put_ok(self, ComponentHandler, resp_mock,
+                              request_mock, mock_policy):
+        mock_policy.return_value = True
         json_update = {'name': 'update_foo',
                        'description': 'update_desc_component',
                        'user_id': 'user_id_test',
@@ -95,8 +98,8 @@ class TestComponentController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
 
     def test_component_delete_not_found(self, ComponentHandler,
-                                        resp_mock, request_mock):
-        self.policy({'delete_component': '@'})
+                                        resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_delete = ComponentHandler.return_value.delete
         hand_delete.side_effect = exception.ResourceNotFound(
             name='component', component_id='test_id')
@@ -106,8 +109,8 @@ class TestComponentController(base.BaseTestCase):
         self.assertEqual(404, resp_mock.status)
 
     def test_component_delete_ok(self, ComponentHandler,
-                                 resp_mock, request_mock):
-        self.policy({'delete_component': '@'})
+                                 resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_delete = ComponentHandler.return_value.delete
         hand_delete.return_value = None
         obj = component.ComponentController('test_id')
@@ -116,6 +119,7 @@ class TestComponentController(base.BaseTestCase):
         self.assertEqual(204, resp_mock.status)
 
 
+@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.component_handler.ComponentHandler')
@@ -124,8 +128,9 @@ class TestComponentsController(base.BaseTestCase):
         super(TestComponentsController, self).setUp()
         objects.load()
 
-    def test_components_get_all(self, handler_mock, resp_mock, request_mock):
-        self.policy({'get_components': '@'})
+    def test_components_get_all(self, handler_mock, resp_mock,
+                                request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get_all = handler_mock.return_value.get_all
         fake_component = fakes.FakeComponent()
         hand_get_all.return_value = [fake_component]
@@ -138,12 +143,13 @@ class TestComponentsController(base.BaseTestCase):
                          resp['result'][0].description)
         self.assertEqual(200, resp_mock.status)
 
-    def test_components_post(self, handler_mock, resp_mock, request_mock):
-        self.policy({'create_component': '@'})
+    def test_components_post(self, handler_mock, resp_mock,
+                             request_mock, mock_policy):
         json_create = {'name': 'foo',
                        'description': 'test_desc_component',
                        'user_id': 'user_id_test',
                        'project_id': 'project_id_test'}
+        mock_policy.return_value = True
         request_mock.body = json.dumps(json_create)
         request_mock.content_type = 'application/json'
         handler_create = handler_mock.return_value.create
@@ -154,8 +160,8 @@ class TestComponentsController(base.BaseTestCase):
         handler_create.assert_called_once_with(json_create)
 
     def test_components_post_nodata(self, handler_mock,
-                                    resp_mock, request_mock):
-        self.policy({'create_component': '@'})
+                                    resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = ''
         request_mock.content_type = 'application/json'
         handler_create = handler_mock.return_value.create
