@@ -31,8 +31,9 @@ class TestPlanModuleFunctions(base.BaseTestCase):
     def test_yaml_content(self, mock_req):
         m = fakes.FakePlan()
         ref_content = plan.yaml_content(m)
+        host_url = pecan.request.application_url.rstrip('/')
         self.assertEqual(ref_content['uri'], '%s/v1/plans/%s' %
-                                             (pecan.request.host_url, m.uuid))
+                                             (host_url, m.uuid))
 
     @mock.patch('solum.api.controllers.v1.plan.init_plan_v1')
     def test_init_plan_by_version(self, init_plan_v1):
@@ -70,6 +71,7 @@ class TestPlanModuleFunctions(base.BaseTestCase):
                           yml_input_plan)
 
 
+@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.plan_handler.PlanHandler')
@@ -78,8 +80,9 @@ class TestPlanController(base.BaseTestCase):
         super(TestPlanController, self).setUp()
         objects.load()
 
-    def test_plan_get_yaml(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'show_plan': '@'})
+    def test_plan_get_yaml(self, PlanHandler, resp_mock,
+                           request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.accept = 'application/x-yaml'
         hand_get = PlanHandler.return_value.get
         fake_plan = fakes.FakePlan()
@@ -92,8 +95,9 @@ class TestPlanController(base.BaseTestCase):
         hand_get.assert_called_with('test_id')
         self.assertEqual(200, resp_mock.status)
 
-    def test_plan_get_json(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'show_plan': '@'})
+    def test_plan_get_json(self, PlanHandler, resp_mock,
+                           request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = PlanHandler.return_value.get
         fake_plan = fakes.FakePlan()
         hand_get.return_value = fake_plan
@@ -109,8 +113,8 @@ class TestPlanController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
 
     def test_plan_get_not_found_yaml(self, PlanHandler,
-                                     resp_mock, request_mock):
-        self.policy({'show_plan': '@'})
+                                     resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.accept = 'application/x-yaml'
         hand_get = PlanHandler.return_value.get
         hand_get.side_effect = exception.ResourceNotFound(name='plan',
@@ -120,8 +124,8 @@ class TestPlanController(base.BaseTestCase):
         self.assertEqual(404, resp_mock.status)
 
     def test_plan_get_not_found_json(self, PlanHandler,
-                                     resp_mock, request_mock):
-        self.policy({'show_plan': '@'})
+                                     resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = PlanHandler.return_value.get
         hand_get.side_effect = exception.ResourceNotFound(name='plan',
                                                           id='test_id')
@@ -129,8 +133,9 @@ class TestPlanController(base.BaseTestCase):
         hand_get.assert_called_with('test_id')
         self.assertEqual(404, resp_mock.status)
 
-    def test_plan_put_none(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_none(self, PlanHandler, resp_mock,
+                           request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.content_type = 'application/x-yaml'
         request_mock.body = ''
         hand_update = PlanHandler.return_value.update
@@ -138,8 +143,9 @@ class TestPlanController(base.BaseTestCase):
         plan.PlanController('test_id').put()
         self.assertEqual(400, resp_mock.status)
 
-    def test_plan_put_needs_name(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_needs_name(self, PlanHandler, resp_mock,
+                                 request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.content_type = 'application/x-yaml'
         request_mock.body = 'version: 1\n'
         hand_update = PlanHandler.return_value.update
@@ -147,8 +153,9 @@ class TestPlanController(base.BaseTestCase):
         plan.PlanController('test_id').put()
         self.assertEqual(400, resp_mock.status)
 
-    def test_plan_put_bad_names(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_bad_names(self, PlanHandler, resp_mock,
+                                request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.content_type = 'application/x-yaml'
         hand_update = PlanHandler.return_value.update
         hand_update.return_value = fakes.FakePlan()
@@ -161,8 +168,9 @@ class TestPlanController(base.BaseTestCase):
         pc.put()
         self.assertEqual(400, resp_mock.status)
 
-    def test_plan_put_invalid_yaml(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_invalid_yaml(self, PlanHandler, resp_mock,
+                                   request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.content_type = 'application/x-yaml'
         request_mock.body = 'invalid yaml file'
         hand_update = PlanHandler.return_value.update
@@ -170,8 +178,9 @@ class TestPlanController(base.BaseTestCase):
         plan.PlanController('test_id').put()
         self.assertEqual(400, resp_mock.status)
 
-    def test_plan_put_empty_yaml(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_empty_yaml(self, PlanHandler, resp_mock,
+                                 request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.content_type = 'application/x-yaml'
         request_mock.body = '{}'
         hand_update = PlanHandler.return_value.update
@@ -179,8 +188,9 @@ class TestPlanController(base.BaseTestCase):
         plan.PlanController('test_id').put()
         self.assertEqual(400, resp_mock.status)
 
-    def test_plan_put_not_found(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_not_found(self, PlanHandler, resp_mock,
+                                request_mock, mock_policy):
+        mock_policy.return_value = True
         data = 'version: 1\nname: ex_plan1\ndescription: dsc1.'
         request_mock.body = data
         request_mock.content_type = 'application/x-yaml'
@@ -192,8 +202,9 @@ class TestPlanController(base.BaseTestCase):
                                                    'description': u'dsc1.'})
         self.assertEqual(404, resp_mock.status)
 
-    def test_plan_put_ok_yaml(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_ok_yaml(self, PlanHandler, resp_mock,
+                              request_mock, mock_policy):
+        mock_policy.return_value = True
         data = 'version: 1\nname: ex_plan1\ndescription: dsc1.'
         request_mock.body = data
         request_mock.content_type = 'application/x-yaml'
@@ -204,8 +215,9 @@ class TestPlanController(base.BaseTestCase):
                                                    'description': u'dsc1.'})
         self.assertEqual(200, resp_mock.status)
 
-    def test_plan_put_ok_json(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+    def test_plan_put_ok_json(self, PlanHandler, resp_mock,
+                              request_mock, mock_policy):
+        mock_policy.return_value = True
         data = {'name': 'foo', 'version': '1'}
         request_mock.body = json.dumps(data)
         request_mock.content_type = 'application/json'
@@ -216,8 +228,8 @@ class TestPlanController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
 
     def test_plan_put_wrong_version_yaml(self, PlanHandler,
-                                         resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+                                         resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         data = 'name: ex_plan1\ndescription: yaml plan1.\nversion: 42'
         request_mock.body = data
         request_mock.content_type = 'application/x-yaml'
@@ -227,8 +239,9 @@ class TestPlanController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plan_put_version_not_found_yaml(self, PlanHandler,
-                                             resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+                                             resp_mock, request_mock,
+                                             mock_policy):
+        mock_policy.return_value = True
         data = 'name: ex_plan1\ndescription: yaml plan1.'
         request_mock.body = data
         request_mock.content_type = 'application/x-yaml'
@@ -238,8 +251,8 @@ class TestPlanController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plan_put_wrong_version_json(self, PlanHandler,
-                                         resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+                                         resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         data = {'name': 'foo', 'version': '42'}
         request_mock.body = json.dumps(data)
         request_mock.content_type = 'application/json'
@@ -249,8 +262,9 @@ class TestPlanController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plan_put_version_not_found_json(self, PlanHandler,
-                                             resp_mock, request_mock):
-        self.policy({'update_plan': '@'})
+                                             resp_mock, request_mock,
+                                             mock_policy):
+        mock_policy.return_value = True
         data = {'name': 'foo'}
         request_mock.body = json.dumps(data)
         request_mock.content_type = 'application/json'
@@ -259,8 +273,9 @@ class TestPlanController(base.BaseTestCase):
         plan.PlanController('test_id').put()
         self.assertEqual(400, resp_mock.status)
 
-    def test_plan_delete_not_found(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'delete_plan': '@'})
+    def test_plan_delete_not_found(self, PlanHandler, resp_mock,
+                                   request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_delete = PlanHandler.return_value.delete
         hand_delete.side_effect = exception.ResourceNotFound(
             name='plan', plan_id='test_id')
@@ -269,8 +284,9 @@ class TestPlanController(base.BaseTestCase):
         hand_delete.assert_called_with('test_id')
         self.assertEqual(404, resp_mock.status)
 
-    def test_plan_delete_ok(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'delete_plan': '@'})
+    def test_plan_delete_ok(self, PlanHandler, resp_mock,
+                            request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_delete = PlanHandler.return_value.delete
         hand_delete.return_value = None
         obj = plan.PlanController('test_id')
@@ -278,8 +294,9 @@ class TestPlanController(base.BaseTestCase):
         hand_delete.assert_called_with('test_id')
         self.assertEqual(202, resp_mock.status)
 
-    def test_plan_delete_dberror(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'delete_plan': '@'})
+    def test_plan_delete_dberror(self, PlanHandler, resp_mock,
+                                 request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = PlanHandler.return_value.get
         fake_plan = fakes.FakePlan()
         hand_get.return_value = fake_plan
@@ -292,6 +309,7 @@ class TestPlanController(base.BaseTestCase):
         self.assertEqual(409, resp_mock.status)
 
 
+@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.plan_handler.PlanHandler')
@@ -300,8 +318,9 @@ class TestPlansController(base.BaseTestCase):
         super(TestPlansController, self).setUp()
         objects.load()
 
-    def test_plans_get_all_yaml(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'get_plans': '@'})
+    def test_plans_get_all_yaml(self, PlanHandler, resp_mock,
+                                request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = PlanHandler.return_value.get_all
         request_mock.accept = 'application/x-yaml'
         fake_plan = fakes.FakePlan()
@@ -313,8 +332,9 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
         hand_get.assert_called_with()
 
-    def test_plans_get_all_json(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'get_plans': '@'})
+    def test_plans_get_all_json(self, PlanHandler, resp_mock,
+                                request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = PlanHandler.return_value.get_all
         fake_plan = fakes.FakePlan()
         hand_get.return_value = [fake_plan]
@@ -325,8 +345,9 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
         hand_get.assert_called_with()
 
-    def test_plans_post_yaml(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+    def test_plans_post_yaml(self, PlanHandler, resp_mock,
+                             request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = 'version: 1\nname: ex_plan1\ndescription: dsc1.'
         request_mock.content_type = 'application/x-yaml'
         hand_create = PlanHandler.return_value.create
@@ -336,8 +357,9 @@ class TestPlansController(base.BaseTestCase):
                                         'description': 'dsc1.'})
         self.assertEqual(201, resp_mock.status)
 
-    def test_plans_post_json(self, PlanHandler, resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+    def test_plans_post_json(self, PlanHandler, resp_mock,
+                             request_mock, mock_policy):
+        mock_policy.return_value = True
         json_update = {'name': 'foo', 'version': '1'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -348,8 +370,9 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(201, resp_mock.status)
 
     def test_plans_post_wrong_version_yaml(self, PlanHandler,
-                                           resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+                                           resp_mock, request_mock,
+                                           mock_policy):
+        mock_policy.return_value = True
         request_mock.body = 'version: 42\nname: ex_plan1\ndescription: dsc1.'
         request_mock.content_type = 'application/x-yaml'
         hand_create = PlanHandler.return_value.create
@@ -358,8 +381,9 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plans_post_version_not_found_yaml(self, PlanHandler,
-                                               resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+                                               resp_mock, request_mock,
+                                               mock_policy):
+        mock_policy.return_value = True
         request_mock.body = 'name: ex_plan1\ndescription: dsc1.'
         request_mock.content_type = 'application/x-yaml'
         hand_create = PlanHandler.return_value.create
@@ -368,8 +392,9 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plans_post_wrong_version_json(self, PlanHandler,
-                                           resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+                                           resp_mock, request_mock,
+                                           mock_policy):
+        mock_policy.return_value = True
         json_update = {'name': 'foo', 'version': '42'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -379,8 +404,9 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plans_post_version_not_found_json(self, PlanHandler,
-                                               resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+                                               resp_mock, request_mock,
+                                               mock_policy):
+        mock_policy.return_value = True
         json_update = {'name': 'foo'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -389,8 +415,9 @@ class TestPlansController(base.BaseTestCase):
         plan.PlansController().post()
         self.assertEqual(400, resp_mock.status)
 
-    def test_plans_post_nodata(self, handler_mock, resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+    def test_plans_post_nodata(self, handler_mock, resp_mock,
+                               request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = ''
         request_mock.content_type = 'application/json'
         handler_create = handler_mock.return_value.create
@@ -399,8 +426,8 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plans_post_invalid_yaml(self, handler_mock,
-                                     resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+                                     resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = 'invalid yaml file'
         request_mock.content_type = 'application/x-yaml'
         handler_create = handler_mock.return_value.create
@@ -409,8 +436,8 @@ class TestPlansController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_plans_post_empty_yaml(self, handler_mock,
-                                   resp_mock, request_mock):
-        self.policy({'create_plan': '@'})
+                                   resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = '{}'
         request_mock.content_type = 'application/x-yaml'
         handler_create = handler_mock.return_value.create
